Changelog
---------
0.0.8 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Use a wider range of MIME types when updating the dataset.
  [msom]

0.0.7 (2018-09-28)
~~~~~~~~~~~~~~~~~~~

- Adds full text search support for attachments.
  [msom]

- Adds voting booklet attachments.
  [msom]

- Adds a CLI command for importing attachments.
  [msom]

- Makes the update, export and delete vote views to be indifferent to the filters.
  [msom]

- Handles search beeing unavailable.
  [msom]

- Sorts full text search results by rank.
  [msom]

0.0.6 (2018-09-23)
~~~~~~~~~~~~~~~~~~~

- Adds search.
  [msom]

- Uses XLSX for import.
  [msom]

- Uses excel format for CSV export.
  [msom]

0.0.5 (2018-09-18)
~~~~~~~~~~~~~~~~~~~

- Adds XLSX export.
  [msom]

- Improves UI.
  [msom]

- Enables English.
  [msom]

0.0.4 (2018-09-03)
~~~~~~~~~~~~~~~~~~~

- Styles content pages.
  [msom]

0.0.3 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Improves vote(s) views.
  [msom]

- Adds editor options.
  [msom]

- Fixes votes pagination.
  [msom]

0.0.2 (2018-08-31)
~~~~~~~~~~~~~~~~~~~

- Adds the GitHub deploy key.
  [msom]

0.0.1 (2018-08-30)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [msom]
